@@ -50,16 +50,17 @@ end subroutine rectangle_int
 
 !------------------------------------------
 
-subroutine gausss( nmax, a, b, x )
+subroutine gausss( a, b, x )
 ! ʬԥܥåդξõˡ
   implicit none
-  integer, intent(in) :: nmax  ! ǿ
-  real, intent(inout) :: a(nmax,nmax)  !  ( 1 ǤԤɽ)
-  real, intent(inout) :: b(nmax)
-  real, intent(inout) :: x(nmax)
+  real, intent(inout) :: b(:)
+  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤԤɽ)
+  real, intent(inout) :: x(size(b))
   real :: s, pivotb
-  real :: pivot(nmax+1)
-  integer :: piv, i, j, k
+  real :: pivot(size(b)+1)
+  integer :: piv, i, j, k, nmax
+
+  nmax=size(b)
 
 !-- ʾõ ---
 !-- A(I,J) ʾõ ---
@@ -115,21 +116,22 @@ end subroutine gausss
 
 !------------------------------------------
 
-subroutine LU_devs( nmax, a, b, x, itermax )
+subroutine LU_devs( a, b, x, itermax )
 !-- LU ʬ׻륵֥롼 ---
   implicit none
-  integer, intent(in) :: nmax  ! ǿ
-  real, intent(inout) :: a(nmax,nmax)  !  ( 1 ǤԤɽ)
-  real, intent(inout) :: b(nmax)  ! դΥ٥ȥ
-  real, intent(inout) :: x(nmax)  ! 
-  real :: d(nmax,nmax), r(nmax), y(nmax)
-  integer :: ip(nmax)
-  real :: scale(nmax), dx(nmax)
+  real, intent(inout) :: b(:)  ! դΥ٥ȥ
+  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤԤɽ)
+  real, intent(inout) :: x(size(b))  ! 
+  real :: d(size(b),size(b)), r(size(b)), y(size(b))
+  integer :: ip(size(b))
+  real :: scale(size(b)), dx(size(b))
   real :: s, t, pivot, xnorm, dxnorm
   real :: s1, s2, s3, s4, s5, t0, t1, t2, t3, t4, eps
-  integer :: iter, itermax
+  integer :: iter, itermax, nmax
   integer :: p, itemp, i, j, k
 
+  nmax=size(b)
+
 !-- ȿɤǤ٤ ---
   t4=6.0
 
@@ -273,22 +275,23 @@ end subroutine LU_devs
 
 !------------------------------------------
 
-subroutine Gau_Sei(nx, a, b, eps, x)
+subroutine Gau_Sei(a, b, eps, x)
   ! ǥˡˤϢΩ 1 
   implicit none
-  integer, intent(in) :: nx  !  1 ʬǿ
-  real, intent(inout) :: a(nx,nx)  !  ( 1 Ǥιʬɽ)
-  real, intent(inout) :: b(nx)  ! ax=b Υ٥ȥ
+  real, intent(inout) :: b(:)  ! ax=b Υ٥ȥ
+  real, intent(inout) :: a(size(b),size(b))  !  ( 1 Ǥιʬɽ)
   real, intent(in) :: eps  ! «
-  real, intent(inout) :: x(nx)  ! 򤯲
+  real, intent(inout) :: x(size(b))  ! 򤯲
   integer :: i, j, k, l, m, n  ! ƥ졼ź
   real :: xn  !  x(i) Υƥΰ
   real :: err, err_max  ! 
+  integer :: nx
 !-- ͤ 0.0 饹Ȥ ---
   x=0.0
+  nx=size(b)
 
 !-- ԥܥåƥ
-  call Pivot_part( nx, a, b )
+  call Pivot_part( a, b )
 
 !-- ʲ, while Ѥ뤿, 1 ܤΥƥ졼ȤñȤǹԤ ---
   err_max=0.0
@@ -342,23 +345,26 @@ end subroutine Gau_Sei
 
 !------------------------------------------
 
-subroutine Jacobi_algebra(nx, a, b, eps, x)
+subroutine Jacobi_algebra(a, b, eps, x)
   ! 䥳ˡˤϢΩ 1 
   implicit none
-  integer, intent(in) :: nx  !  1 ʬǿ
-  real, intent(inout) :: a(nx,nx)  !  ( 1 ǤιԤɽ)
-  real, intent(inout) :: b(nx)  ! ax=b Υ٥ȥ
+  real, intent(inout) :: b(:)  ! ax=b Υ٥ȥ
+  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤιԤɽ)
   real, intent(in) :: eps  ! «
-  real, intent(inout) :: x(nx)  ! 򤯲
-  real :: y(nx)  ! 䥳ˡǻѤǼ, ǰƹ.(xn )
+  real, intent(inout) :: x(size(b))  ! 򤯲
+  real :: y(size(b))  ! 䥳ˡǻѤǼ, ǰƹ.(xn )
   integer :: i, j, k, l, m, n  ! ƥ졼ź
   real :: err, err_max  ! 
+  integer :: nx
+
+  nx=size(b)
+
 !-- ͤ 0,0 饹Ȥ ---
   x=0.0
   y=0.0
 
 !-- ԥܥåƥ
-  call Pivot_part( nx, a, b )
+  call Pivot_part( a, b )
 
 !-- ʲ, ºݤΥ(while Ѥ뤿, 1 ܤΥƥ졼ȤñȤǹԤ) ---
   err_max=0.0
@@ -414,19 +420,21 @@ end subroutine Jacobi_algebra
 
 !------------------------------------------
 
-subroutine SOR_Gau_Sei(nx, a, b, eps, accel, x)
+subroutine SOR_Gau_Sei(a, b, eps, accel, x)
   ! ǥˡ, SOR ǲ®ˤϢΩ 1 
   implicit none
-  integer, intent(in) :: nx  !  1 ʬǿ
-  real, intent(inout) :: a(nx,nx)  !  ( 1 ǤιԤɽ)
-  real, intent(inout) :: b(nx)  ! ax=b Υ٥ȥ
+  real, intent(inout) :: b(:)  ! ax=b Υ٥ȥ
+  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤιԤɽ)
   real, intent(in) :: eps  ! «
   real, intent(in) :: accel  ! ®. , Ū accel >= 2 ǤȯΤ,
                              ! Ͱʾ夬ꤵȥ顼ǻߤ.
-  real, intent(inout) :: x(nx)  ! 򤯲
+  real, intent(inout) :: x(size(b))  ! 򤯲
   integer :: i, j, k, l, m, n  ! ƥ졼ź
   real :: xn  !  x(i) Υƥΰ
   real :: err, err_max  ! 
+  integer :: nx
+
+  nx=size(b)
 
 !-- ®ѥ᡼γǧ
   if(accel>=2.0)then
@@ -439,7 +447,7 @@ subroutine SOR_Gau_Sei(nx, a, b, eps, accel, x)
   x=0.0
 
 !-- ԥܥåƥ
-  call Pivot_part( nx, a, b )
+  call Pivot_part( a, b )
 
 !-- ʲ, while Ѥ뤿, 1 ܤΥƥ졼ȤñȤǹԤ ---
   err_max=0.0
@@ -495,19 +503,21 @@ end subroutine SOR_Gau_Sei
 
 !------------------------------------------
 
-subroutine SOR_Jacobi_algebra(nx, a, b, eps, accel, x)
+subroutine SOR_Jacobi_algebra(a, b, eps, accel, x)
   ! 䥳ˡ SOR ®ˤϢΩ 1 
   implicit none
-  integer, intent(in) :: nx  !  1 ʬǿ
-  real, intent(inout) :: a(nx,nx)  !  ( 1 ǤιԤɽ)
-  real, intent(inout) :: b(nx)  ! ax=b Υ٥ȥ
+  real, intent(inout) :: b(:)  ! ax=b Υ٥ȥ
+  real, intent(inout) :: a(size(b),size(b))  !  ( 1 ǤιԤɽ)
   real, intent(in) :: eps  ! «
   real, intent(in) :: accel  ! ®. , Ū accel >= 2 ǤȯΤ,
                              ! Ͱʾ夬ꤵȥ顼ǻߤ.
-  real, intent(inout) :: x(nx)  ! 򤯲
-  real :: y(nx)  ! 䥳ˡǻѤǼ, ǰƹ.(xn )
+  real, intent(inout) :: x(size(b))  ! 򤯲
+  real :: y(size(b))  ! 䥳ˡǻѤǼ, ǰƹ.(xn )
   integer :: i, j, k, l, m, n  ! ƥ졼ź
   real :: err, err_max  ! 
+  integer :: nx
+
+  nx=size(b)
 
 !-- ®ѥ᡼γǧ
   if(accel>=2.0)then
@@ -521,7 +531,7 @@ subroutine SOR_Jacobi_algebra(nx, a, b, eps, accel, x)
   y=0.0
 
 !-- ԥܥåƥ
-  call Pivot_part( nx, a, b )
+  call Pivot_part( a, b )
 
 !-- ʲ, ºݤΥ(while Ѥ뤿, 1 ܤΥƥ졼ȤñȤǹԤ) ---
   err_max=0.0
@@ -578,17 +588,19 @@ end subroutine SOR_Jacobi_algebra
 
 !-----------------------------------------
 
-subroutine eigenvalue_power( nx, a, eps, eigenval, eigenvec )
+subroutine eigenvalue_power( a, eps, eigenval, eigenvec )
 ! ٤ˡѤƹκͭͤȤθͭͤбͭ٥ȥ.
   implicit none
-  integer, intent(in) :: nx  ! ǿ
-  real, intent(in) :: a(nx,nx)  ! ͭͤ ( 1 ǤԤɽ)
+  real, intent(inout) :: eigenvec(:)  ! ͭ٥ȥ
+  real, intent(in) :: a(size(eigenvec),size(eigenvec))  ! ͭͤ ( 1 ǤԤɽ)
   real, intent(in) :: eps  ! «Ƚ
   real, intent(inout) :: eigenval  !  a κͭ
-  real, intent(inout) :: eigenvec(nx)  ! ͭ٥ȥ
   integer :: i, j, k
-  real, dimension(nx) :: x, y
+  real, dimension(size(eigenvec)) :: x, y
   real :: tmp1, tmp2, err_max, err
+  integer :: nx
+
+  nx=size(eigenvec)
 
   do i=1,nx
      x(i)=1.0  ! ȿˡνͤȤ󥼥Υ٥ȥ
@@ -636,17 +648,19 @@ end subroutine eigenvalue_power
 
 !------------------------------------------
 
-subroutine invert_mat( nx, ax, xx )
+subroutine invert_mat( ax, xx )
 ! ξõˡĥ, չ׻.
 ! Ūˤ, դ b ñ̥٥ȥ 1 Ĥ,õ̤Υ٥ȥ¤٤
 ! չˤ.
   implicit none
-  integer, intent(in) :: nx  ! ǿ
-  real, intent(in) :: ax(nx,nx)  ! չ
-  real, intent(inout) :: xx(nx,nx)  ! ᤿չ
+  real, intent(in) :: ax(:,:)  ! չ
+  real, intent(inout) :: xx(size(ax,1),size(ax,2))  ! ᤿չ
   integer :: i, j, k
-  real :: c(nx,nx)  ! ñ̹
-  real :: d(nx,nx)  ! a(i,j) 򥬥롼Ϥ, ̤ѲΤǤ˰
+  real :: c(size(ax,1),size(ax,2))  ! ñ̹
+  real :: d(size(ax,1),size(ax,2))  ! a(i,j) 򥬥롼Ϥ, ̤ѲΤǤ˰
+  integer :: nx
+
+  nx=size(ax,1)
 
   c=0.0
 
@@ -662,7 +676,7 @@ subroutine invert_mat( nx, ax, xx )
         end do
      end do
 
-     call gausss( nx, d, c(:,i), xx(:,i) )  !  2 ʬɽΤ, ν֤ OK.
+     call gausss( d, c(:,i), xx(:,i) )  !  2 ʬɽΤ, ν֤ OK.
   end do
 
 end subroutine invert_mat
@@ -716,15 +730,17 @@ end subroutine schumit_norm
 ! ʲ, private °դ롼
 !-----------------------------------------
 
-subroutine Pivot_part( nx, a, b )
+subroutine Pivot_part( a, b )
 ! гʬ¸ߤ를ԥܥåƥ󥰤ˤä󥼥֤ͤ.
   implicit none
-  integer, intent(in) :: nx  ! ǿ
-  real, intent(inout) :: a(nx,nx)  ! ԥܥåƥ󥰤Ԥ ( 1 ǤԤб)
-  real, intent(inout) :: b(nx)  ! ԥܥåƥ󥰤ȤȤ֤뱦ե٥ȥ
-  real :: tmp(nx)  ! ؤΰ
+  real, intent(inout) :: b(:)  ! ԥܥåƥ󥰤ȤȤ֤뱦ե٥ȥ
+  real, intent(inout) :: a(size(b),size(b))  ! ԥܥåƥ󥰤Ԥ ( 1 ǤԤб)
+  real :: tmp(size(b))  ! ؤΰ
   real :: tmpv  ! ؤȼ b(i) 򤵤ѿ
   integer :: i, j, k
+  integer :: nx
+
+  nx=size(b)
 
   do i=1,nx
      if(a(i,i)==0.0)then
