@@ -78,13 +78,28 @@ end function
 !--------------------------------------------------------
 !--------------------------------------------------------
 
-real function ust( cmd, va )
-! ໤® u_* ׻ؿ
+real function cmdva_2_ust( cmd, va )
+! Х륯, ®٤໤® u_* ׻ؿ
   implicit none
   real, intent(in) :: cmd  !  za ǤΥХ륯
   real, intent(in) :: va  !  za Ǥοʿ [m/s]
 
-  ust=va*sqrt(cmd)
+  cmdva_2_ust=va*sqrt(cmd)
+
+end function
+
+!--------------------------------------------------------
+!--------------------------------------------------------
+
+real function taurho_2_ust( tau, rho )
+! ϤΥǥȿʿ 2 ʬȤι٤Ǥ̩٤໤® u_* ׻ؿ
+  implicit none
+  real, intent(in) :: tau(2)  ! ٤ǤϤΥǥȿʿ 2 ʬ [N/m]
+  real, intent(in) :: rho  ! ٤Ǥ̩ [kg/m^3]
+  real :: taua
+
+  taua=sqrt(tau(1)**2+tau(2)**2)
+  taurho_2_ust=sqrt(taua/rho)
 
 end function
 
@@ -124,7 +139,7 @@ real function precip_water( p, qv, undef )  ! Ĺ߿̤׻. ñ̤ [kg/m^2]
   end if
 
   call rectangle_int( tmp_p, tmp_qv, tmp_p(nx), tmp_p(1), precip )
-write(*,*) "precip", precip, tmp_qv(1), tmp_qv(nx)
+
   precip_water=-precip/g
 
   return
